.ordering-buttons{
	margin-bottom:5px;
	margin-top:5px;
	width:121px;
	position: relative;
	height:110px;

}
.ordering-buttons ul{
	position:absolute;
	float:left;
	margin-right: 5px;
	overflow: visible;
}
.ordering-buttons .jump-container{
	top:37px;
	left:62px;
	width:60px;
}
.ordering-buttons .move-container{
	top:0px;
	left:31px;
}

.ordering-buttons .drag-container{
	top:37px;
}

.ordering-buttons .move-container li{
	float:none;
	margin:0;
	padding:0;
}

.ordering-buttons a{
	border: 1px solid #ccc;
	
	background-color:#eee;
	text-indent: -9999px;
	width: 26px;
	height: 20px;

	margin:0;
}
.ordering-buttons a:hover{
	background-color:#ddd;					
}

.ordering-buttons .drag{

	-webkit-border-radius: 5px;
	border-radius: 5px;		
	
}
.ordering-buttons .drag.disabled{
	cursor: default;
	pointer-events: none;
	background-color: rgb(220, 220, 220);
}
.ordering-buttons .move_top{					
	
	-webkit-border-radius: 5px 5px 0px 0px;
	border-radius: 5px 5px 0px 0px;
	
}
.ordering-buttons .move_top.disabled{
	cursor: default;
	pointer-events: none;
	background-color: rgb(220, 220, 220);
}
.ordering-buttons .move_up{					
	
	-webkit-border-radius: 0;
	border-radius: 0;	
	border-top:0;	
}
.ordering-buttons .move_up.disabled{
	cursor: default;	
	pointer-events: none;
	background-color: rgb(220, 220, 220);
}
.ordering-buttons .move_down{
	
	-webkit-border-radius: 0;
	border-radius: 0;
	border-top:0;			
}
.ordering-buttons .move_down.disabled{
	cursor: default;
	pointer-events: none;
	background-color: rgb(220, 220, 220);
}
.ordering-buttons .move_bottom{
	-webkit-border-radius: 0px 0px 5px 5px;	
	border-radius: 0px 0px 5px 5px;		

	border-top:0px;				
	
}
.ordering-buttons .move_bottom.disabled{
	cursor: default;
	pointer-events: none;
	background-color: rgb(220, 220, 220);
}

.ordering-buttons .new_value{
	width:30px;
	height:30px;

	font-size:11px;
	text-align: right;
	-webkit-border-radius: 5px 0px 0px 5px;	
	border-radius: 5px 0px 0px 5px;	

	margin-right:-4px;
	position:static;
}
.ordering-buttons .apply_new_value{


	-webkit-border-radius: 0px 5px 5px 0px;
	border-radius: 0px 5px 5px 0px;
	
	width:18px;
	height:21px;
	text-indent: 0;
	font-weight: bold;
	font-size: 16px;
	padding: 7px 0 0 8px;
}
.ordering-buttons .apply_new_value.disabled{
	cursor: default;
	pointer-events: none;
	background-color: rgb(220, 220, 220);
}
.ordering-buttons .original_value{
	display:none;
}
.ordering-buttons .delete{
	
	-webkit-border-radius: 5px 0px 0px 5px;
	border-radius: 5px 0px 0px 5px;		

	margin-left:5px;
	border-right:0;	

}

.ordering-buttons .move_bottom, 
.ordering-buttons .move_down,
.ordering-buttons .move_up,
.ordering-buttons .move_top{
	display:block;
}


.list-item-initialized .ordering-buttons + input{
	display: none;
}